#!/bin/bash
#
# source: http://ftp.gnome.org/pub/gnome/sources/evolution-data-server/2.26/evolution-data-server-2.26.3.tar.bz2
#
# maintainer: (package seek a maintainers)
#

#------------------ Set Some Variables

buildir=$(pwd)
soft='evolution-data-server'
softlight='evolution-data-server-light'
softversion="2.26.3"
arch="i486"
cpu="i686"
packageversion="62.1"

srcpkg="$buildir/$soft-$softversion.tar.bz2"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"
packagelight="$softlight-$softversion-$arch-$packageversion"
destlight="$buildir/$packagelight"

# ----------------- Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvjf $srcpkg
rm -f $dest.txz
rm -f $dest.tlz
rm -f $dest.tgz
rm -rf $dest
rm -f $dest.tgz
rm -rf $destlight
rm -f $destlight.txz
rm -f $destlight.tlz
rm -f $destlight.tgz

cd $src

chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --enable-static=no \
  --with-krb4=/usr \
  --with-krb5=/usr \
  --enable-gnome-keyring=no \
  --enable-nntp \
  --with-openldap=/usr \
  --with-nspr-includes=/usr/include/nspr \

make -j2
make install DESTDIR=$dest

find $dest | xargs file | grep -e "executable" -e "shared object" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Documentation

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a ChangeLog COPYING INSTALL MAINTAINERS NEWS TODO $dest/usr/doc/$soft-$softversion

mkdir -p $destlight/usr/lib
mv $dest/usr/lib/libedataserver* $destlight/usr/lib
mv $dest/usr/lib/libcamel* $destlight/usr/lib

mkdir -p $dest/install
cat << "EODESC" > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                     |-----handy-ruler---------------------------------------------------|
evolution-data-server: evolution-data-server- Evolution Backend Data Server Library
evolution-data-server:
evolution-data-server: The Evolution Data Server provides a single database for common,
evolution-data-server: desktop-wide information, such as a user's address book or calendar
evolution-data-server: events. It is also a dependency of the clock applet from the
evolution-data-server: gnome-applets package
evolution-data-server:
evolution-data-server:
evolution-data-server:
evolution-data-server:
evolution-data-server:
EODESC

mkdir -p $destlight/install
cat << "EODESC" > $destlight/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

                           |-----handy-ruler-----------------------------------------------|
evolution-data-server-light: evolution-data-server-light - basic libraries of e-d-s
evolution-data-server-light:
evolution-data-server-light: evolution-data-server-light includes some libraries split from
evolution-data-server-light: the evolution-data-server package that are used by the totem
evolution-data-server-light: media player.
evolution-data-server-light:
evolution-data-server-light:
evolution-data-server-light:
evolution-data-server-light:
evolution-data-server-light:
evolution-data-server-light:
EODESC

mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

# Packaging

cd $dest
makepkg -l y -c n $dest.txz
makepkg -l y -c n $dest.tlz
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.txz > $package.md5

cd $destlight
makepkg -l y -c n $destlight.txz
makepkg -l y -c n $destlight.tlz
makepkg -l y -c n $destlight.tgz
cd $buildir
md5sum $packagelight.txz > $packagelight.md5

